# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/http/jwt_authn/v2alpha/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/http/jwt_authn/v2alpha/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/config/filter/http/jwt_authn/v2alpha/config.proto\x12*envoy.config.filter.http.jwt_authn.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a envoy/api/v2/core/http_uri.proto\x1a)envoy/api/v2/route/route_components.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8b\x03\n\x0bJwtProvider\x12\x17\n\x06issuer\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x11\n\taudiences\x18\x02 \x03(\t\x12M\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32\x36.envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwksH\x00\x12\x33\n\nlocal_jwks\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12K\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32\x35.envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12\x1e\n\x16\x66orward_payload_header\x18\x08 \x01(\t\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\tB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"m\n\nRemoteJwks\x12,\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x31\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"8\n\tJwtHeader\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x0cvalue_prefix\x18\x02 \x01(\t\"A\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\"\xc0\x03\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12\x63\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiencesH\x00\x12X\n\x0crequires_any\x18\x03 \x01(\x0b\x32@.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrListH\x00\x12Y\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\x0f\n\rrequires_type\"r\n\x14JwtRequirementOrList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"s\n\x15JwtRequirementAndList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"\x98\x01\n\x0fRequirementRule\x12\x37\n\x05match\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.route.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\x08requires\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement\"\xf2\x01\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12[\n\x08requires\x18\x03 \x03(\x0b\x32I.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry\x1ak\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement:\x02\x38\x01\"\xa3\x03\n\x11JwtAuthentication\x12_\n\tproviders\x18\x01 \x03(\x0b\x32L.envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry\x12J\n\x05rules\x18\x02 \x03(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule\x12W\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x1ai\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider:\x02\x38\x01\x42\xd6\x01\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\x0b\x43onfigProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/jwt_authn/v2alpha\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.jwt_authn.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\013ConfigProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/jwt_authn/v2alpha\362\230\376\217\005,\022*envoy.extensions.filters.http.jwt_authn.v3\272\200\310\321\006\002\020\001'
  _globals['_JWTPROVIDER'].oneofs_by_name['jwks_source_specifier']._loaded_options = None
  _globals['_JWTPROVIDER'].oneofs_by_name['jwks_source_specifier']._serialized_options = b'\370B\001'
  _globals['_JWTPROVIDER'].fields_by_name['issuer']._loaded_options = None
  _globals['_JWTPROVIDER'].fields_by_name['issuer']._serialized_options = b'\372B\004r\002 \001'
  _globals['_JWTHEADER'].fields_by_name['name']._loaded_options = None
  _globals['_JWTHEADER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_JWTREQUIREMENTORLIST'].fields_by_name['requirements']._loaded_options = None
  _globals['_JWTREQUIREMENTORLIST'].fields_by_name['requirements']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_JWTREQUIREMENTANDLIST'].fields_by_name['requirements']._loaded_options = None
  _globals['_JWTREQUIREMENTANDLIST'].fields_by_name['requirements']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_REQUIREMENTRULE'].fields_by_name['match']._loaded_options = None
  _globals['_REQUIREMENTRULE'].fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._loaded_options = None
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_options = b'8\001'
  _globals['_FILTERSTATERULE'].fields_by_name['name']._loaded_options = None
  _globals['_FILTERSTATERULE'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._loaded_options = None
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_options = b'8\001'
  _globals['_JWTPROVIDER']._serialized_start=360
  _globals['_JWTPROVIDER']._serialized_end=755
  _globals['_REMOTEJWKS']._serialized_start=757
  _globals['_REMOTEJWKS']._serialized_end=866
  _globals['_JWTHEADER']._serialized_start=868
  _globals['_JWTHEADER']._serialized_end=924
  _globals['_PROVIDERWITHAUDIENCES']._serialized_start=926
  _globals['_PROVIDERWITHAUDIENCES']._serialized_end=991
  _globals['_JWTREQUIREMENT']._serialized_start=994
  _globals['_JWTREQUIREMENT']._serialized_end=1442
  _globals['_JWTREQUIREMENTORLIST']._serialized_start=1444
  _globals['_JWTREQUIREMENTORLIST']._serialized_end=1558
  _globals['_JWTREQUIREMENTANDLIST']._serialized_start=1560
  _globals['_JWTREQUIREMENTANDLIST']._serialized_end=1675
  _globals['_REQUIREMENTRULE']._serialized_start=1678
  _globals['_REQUIREMENTRULE']._serialized_end=1830
  _globals['_FILTERSTATERULE']._serialized_start=1833
  _globals['_FILTERSTATERULE']._serialized_end=2075
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_start=1968
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_end=2075
  _globals['_JWTAUTHENTICATION']._serialized_start=2078
  _globals['_JWTAUTHENTICATION']._serialized_end=2497
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_start=2392
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_end=2497
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/core/backoff.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/core/backoff.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/api/v2/core/backoff.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8e\x01\n\x0f\x42\x61\x63koffStrategy\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x42\x8f\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0c\x42\x61\x63koffProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.backoff_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\014BackoffProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _globals['_BACKOFFSTRATEGY'].fields_by_name['base_interval']._loaded_options = None
  _globals['_BACKOFFSTRATEGY'].fields_by_name['base_interval']._serialized_options = b'\372B\013\252\001\010\010\0012\004\020\300\204='
  _globals['_BACKOFFSTRATEGY'].fields_by_name['max_interval']._loaded_options = None
  _globals['_BACKOFFSTRATEGY'].fields_by_name['max_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_BACKOFFSTRATEGY']._serialized_start=175
  _globals['_BACKOFFSTRATEGY']._serialized_end=317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/monitored_resource.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/monitored_resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import label_pb2 as google_dot_api_dot_label__pb2
from google.api import launch_stage_pb2 as google_dot_api_dot_launch__stage__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/api/monitored_resource.proto\x12\ngoogle.api\x1a\x16google/api/label.proto\x1a\x1dgoogle/api/launch_stage.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc0\x01\n\x1bMonitoredResourceDescriptor\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12+\n\x06labels\x18\x04 \x03(\x0b\x32\x1b.google.api.LabelDescriptor\x12-\n\x0claunch_stage\x18\x07 \x01(\x0e\x32\x17.google.api.LaunchStage\"\x8b\x01\n\x11MonitoredResource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x39\n\x06labels\x18\x02 \x03(\x0b\x32).google.api.MonitoredResource.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x01\n\x19MonitoredResourceMetadata\x12.\n\rsystem_labels\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12J\n\x0buser_labels\x18\x02 \x03(\x0b\x32\x35.google.api.MonitoredResourceMetadata.UserLabelsEntry\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42y\n\x0e\x63om.google.apiB\x16MonitoredResourceProtoP\x01ZCgoogle.golang.org/genproto/googleapis/api/monitoredres;monitoredres\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.monitored_resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\026MonitoredResourceProtoP\001ZCgoogle.golang.org/genproto/googleapis/api/monitoredres;monitoredres\370\001\001\242\002\004GAPI'
  _globals['_MONITOREDRESOURCE_LABELSENTRY']._loaded_options = None
  _globals['_MONITOREDRESOURCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_MONITOREDRESOURCEMETADATA_USERLABELSENTRY']._loaded_options = None
  _globals['_MONITOREDRESOURCEMETADATA_USERLABELSENTRY']._serialized_options = b'8\001'
  _globals['_MONITOREDRESOURCEDESCRIPTOR']._serialized_start=137
  _globals['_MONITOREDRESOURCEDESCRIPTOR']._serialized_end=329
  _globals['_MONITOREDRESOURCE']._serialized_start=332
  _globals['_MONITOREDRESOURCE']._serialized_end=471
  _globals['_MONITOREDRESOURCE_LABELSENTRY']._serialized_start=426
  _globals['_MONITOREDRESOURCE_LABELSENTRY']._serialized_end=471
  _globals['_MONITOREDRESOURCEMETADATA']._serialized_start=474
  _globals['_MONITOREDRESOURCEMETADATA']._serialized_end=676
  _globals['_MONITOREDRESOURCEMETADATA_USERLABELSENTRY']._serialized_start=627
  _globals['_MONITOREDRESOURCEMETADATA_USERLABELSENTRY']._serialized_end=676
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/rbac/v3/rbac.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/rbac/v3/rbac.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import filter_state_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_filter__state__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from envoy.type.matcher.v3 import path_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_path__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/config/rbac/v3/rbac.proto\x12\x14\x65nvoy.config.rbac.v3\x1a\"envoy/config/core/v3/address.proto\x1a$envoy/config/core/v3/extension.proto\x1a,envoy/config/route/v3/route_components.proto\x1a(envoy/type/matcher/v3/filter_state.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a envoy/type/matcher/v3/path.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a&google/api/expr/v1alpha1/checked.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf5\x05\n\x04RBAC\x12;\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32!.envoy.config.rbac.v3.RBAC.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12:\n\x08policies\x18\x02 \x03(\x0b\x32(.envoy.config.rbac.v3.RBAC.PoliciesEntry\x12M\n\x15\x61udit_logging_options\x18\x03 \x01(\x0b\x32..envoy.config.rbac.v3.RBAC.AuditLoggingOptions\x1a\x8b\x03\n\x13\x41uditLoggingOptions\x12`\n\x0f\x61udit_condition\x18\x01 \x01(\x0e\x32=.envoy.config.rbac.v3.RBAC.AuditLoggingOptions.AuditConditionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12X\n\x0elogger_configs\x18\x02 \x03(\x0b\x32@.envoy.config.rbac.v3.RBAC.AuditLoggingOptions.AuditLoggerConfig\x1aj\n\x11\x41uditLoggerConfig\x12@\n\x0c\x61udit_logger\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x13\n\x0bis_optional\x18\x02 \x01(\x08\"L\n\x0e\x41uditCondition\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07ON_DENY\x10\x01\x12\x0c\n\x08ON_ALLOW\x10\x02\x12\x15\n\x11ON_DENY_AND_ALLOW\x10\x03\x1aM\n\rPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.envoy.config.rbac.v3.Policy:\x02\x38\x01\"&\n\x06\x41\x63tion\x12\t\n\x05\x41LLOW\x10\x00\x12\x08\n\x04\x44\x45NY\x10\x01\x12\x07\n\x03LOG\x10\x02: \x9a\xc5\x88\x1e\x1b\n\x19\x65nvoy.config.rbac.v2.RBAC\"\xdd\x02\n\x06Policy\x12?\n\x0bpermissions\x18\x01 \x03(\x0b\x32 .envoy.config.rbac.v3.PermissionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12=\n\nprincipals\x18\x02 \x03(\x0b\x32\x1f.envoy.config.rbac.v3.PrincipalB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12O\n\tcondition\x18\x03 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprB\x1c\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65xpression_specifier\x12^\n\x11\x63hecked_condition\x18\x04 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprB\x1c\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65xpression_specifier:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.config.rbac.v2.Policy\"\xa6\x01\n\x0fSourcedMetadata\x12J\n\x10metadata_matcher\x18\x01 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12G\n\x0fmetadata_source\x18\x02 \x01(\x0e\x32$.envoy.config.rbac.v3.MetadataSourceB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\xd7\x07\n\nPermission\x12\x39\n\tand_rules\x18\x01 \x01(\x0b\x32$.envoy.config.rbac.v3.Permission.SetH\x00\x12\x38\n\x08or_rules\x18\x02 \x01(\x0b\x32$.envoy.config.rbac.v3.Permission.SetH\x00\x12\x16\n\x03\x61ny\x18\x03 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x36\n\x06header\x18\x04 \x01(\x0b\x32$.envoy.config.route.v3.HeaderMatcherH\x00\x12\x36\n\x08url_path\x18\n \x01(\x0b\x32\".envoy.type.matcher.v3.PathMatcherH\x00\x12\x39\n\x0e\x64\x65stination_ip\x18\x05 \x01(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeH\x00\x12%\n\x10\x64\x65stination_port\x18\x06 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12;\n\x16\x64\x65stination_port_range\x18\x0b \x01(\x0b\x32\x19.envoy.type.v3.Int32RangeH\x00\x12G\n\x08metadata\x18\x07 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x34\n\x08not_rule\x18\x08 \x01(\x0b\x32 .envoy.config.rbac.v3.PermissionH\x00\x12\x45\n\x15requested_server_name\x18\t \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherH\x00\x12=\n\x07matcher\x18\x0c \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x12\x42\n\x0curi_template\x18\r \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x12\x41\n\x10sourced_metadata\x18\x0e \x01(\x0b\x32%.envoy.config.rbac.v3.SourcedMetadataH\x00\x1al\n\x03Set\x12\x39\n\x05rules\x18\x01 \x03(\x0b\x32 .envoy.config.rbac.v3.PermissionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.rbac.v2.Permission.Set:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.rbac.v2.PermissionB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\xb1\x08\n\tPrincipal\x12\x36\n\x07\x61nd_ids\x18\x01 \x01(\x0b\x32#.envoy.config.rbac.v3.Principal.SetH\x00\x12\x35\n\x06or_ids\x18\x02 \x01(\x0b\x32#.envoy.config.rbac.v3.Principal.SetH\x00\x12\x16\n\x03\x61ny\x18\x03 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x46\n\rauthenticated\x18\x04 \x01(\x0b\x32-.envoy.config.rbac.v3.Principal.AuthenticatedH\x00\x12\x41\n\tsource_ip\x18\x05 \x01(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12;\n\x10\x64irect_remote_ip\x18\n \x01(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeH\x00\x12\x34\n\tremote_ip\x18\x0b \x01(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeH\x00\x12\x36\n\x06header\x18\x06 \x01(\x0b\x32$.envoy.config.route.v3.HeaderMatcherH\x00\x12\x36\n\x08url_path\x18\t \x01(\x0b\x32\".envoy.type.matcher.v3.PathMatcherH\x00\x12G\n\x08metadata\x18\x07 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x41\n\x0c\x66ilter_state\x18\x0c \x01(\x0b\x32).envoy.type.matcher.v3.FilterStateMatcherH\x00\x12\x31\n\x06not_id\x18\x08 \x01(\x0b\x32\x1f.envoy.config.rbac.v3.PrincipalH\x00\x12\x41\n\x10sourced_metadata\x18\r \x01(\x0b\x32%.envoy.config.rbac.v3.SourcedMetadataH\x00\x1ah\n\x03Set\x12\x36\n\x03ids\x18\x01 \x03(\x0b\x32\x1f.envoy.config.rbac.v3.PrincipalB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:)\x9a\xc5\x88\x1e$\n\"envoy.config.rbac.v2.Principal.Set\x1a\x88\x01\n\rAuthenticated\x12<\n\x0eprincipal_name\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher:3\x9a\xc5\x88\x1e.\n,envoy.config.rbac.v2.Principal.AuthenticatedJ\x04\x08\x01\x10\x02:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.config.rbac.v2.PrincipalB\x11\n\nidentifier\x12\x03\xf8\x42\x01\"R\n\x06\x41\x63tion\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32!.envoy.config.rbac.v3.RBAC.Action*(\n\x0eMetadataSource\x12\x0b\n\x07\x44YNAMIC\x10\x00\x12\t\n\x05ROUTE\x10\x01\x42}\n\"io.envoyproxy.envoy.config.rbac.v3B\tRbacProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/rbac/v3;rbacv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.rbac.v3.rbac_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.config.rbac.v3B\tRbacProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/rbac/v3;rbacv3\272\200\310\321\006\002\020\002'
  _globals['_RBAC_AUDITLOGGINGOPTIONS'].fields_by_name['audit_condition']._loaded_options = None
  _globals['_RBAC_AUDITLOGGINGOPTIONS'].fields_by_name['audit_condition']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RBAC_POLICIESENTRY']._loaded_options = None
  _globals['_RBAC_POLICIESENTRY']._serialized_options = b'8\001'
  _globals['_RBAC'].fields_by_name['action']._loaded_options = None
  _globals['_RBAC'].fields_by_name['action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RBAC']._loaded_options = None
  _globals['_RBAC']._serialized_options = b'\232\305\210\036\033\n\031envoy.config.rbac.v2.RBAC'
  _globals['_POLICY'].fields_by_name['permissions']._loaded_options = None
  _globals['_POLICY'].fields_by_name['permissions']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_POLICY'].fields_by_name['principals']._loaded_options = None
  _globals['_POLICY'].fields_by_name['principals']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_POLICY'].fields_by_name['condition']._loaded_options = None
  _globals['_POLICY'].fields_by_name['condition']._serialized_options = b'\362\230\376\217\005\026\022\024expression_specifier'
  _globals['_POLICY'].fields_by_name['checked_condition']._loaded_options = None
  _globals['_POLICY'].fields_by_name['checked_condition']._serialized_options = b'\362\230\376\217\005\026\022\024expression_specifier'
  _globals['_POLICY']._loaded_options = None
  _globals['_POLICY']._serialized_options = b'\232\305\210\036\035\n\033envoy.config.rbac.v2.Policy'
  _globals['_SOURCEDMETADATA'].fields_by_name['metadata_matcher']._loaded_options = None
  _globals['_SOURCEDMETADATA'].fields_by_name['metadata_matcher']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_SOURCEDMETADATA'].fields_by_name['metadata_source']._loaded_options = None
  _globals['_SOURCEDMETADATA'].fields_by_name['metadata_source']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PERMISSION_SET'].fields_by_name['rules']._loaded_options = None
  _globals['_PERMISSION_SET'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_PERMISSION_SET']._loaded_options = None
  _globals['_PERMISSION_SET']._serialized_options = b'\232\305\210\036%\n#envoy.config.rbac.v2.Permission.Set'
  _globals['_PERMISSION'].oneofs_by_name['rule']._loaded_options = None
  _globals['_PERMISSION'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_PERMISSION'].fields_by_name['any']._loaded_options = None
  _globals['_PERMISSION'].fields_by_name['any']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_PERMISSION'].fields_by_name['destination_port']._loaded_options = None
  _globals['_PERMISSION'].fields_by_name['destination_port']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _globals['_PERMISSION'].fields_by_name['metadata']._loaded_options = None
  _globals['_PERMISSION'].fields_by_name['metadata']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_PERMISSION']._loaded_options = None
  _globals['_PERMISSION']._serialized_options = b'\232\305\210\036!\n\037envoy.config.rbac.v2.Permission'
  _globals['_PRINCIPAL_SET'].fields_by_name['ids']._loaded_options = None
  _globals['_PRINCIPAL_SET'].fields_by_name['ids']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_PRINCIPAL_SET']._loaded_options = None
  _globals['_PRINCIPAL_SET']._serialized_options = b'\232\305\210\036$\n\"envoy.config.rbac.v2.Principal.Set'
  _globals['_PRINCIPAL_AUTHENTICATED']._loaded_options = None
  _globals['_PRINCIPAL_AUTHENTICATED']._serialized_options = b'\232\305\210\036.\n,envoy.config.rbac.v2.Principal.Authenticated'
  _globals['_PRINCIPAL'].oneofs_by_name['identifier']._loaded_options = None
  _globals['_PRINCIPAL'].oneofs_by_name['identifier']._serialized_options = b'\370B\001'
  _globals['_PRINCIPAL'].fields_by_name['any']._loaded_options = None
  _globals['_PRINCIPAL'].fields_by_name['any']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_PRINCIPAL'].fields_by_name['source_ip']._loaded_options = None
  _globals['_PRINCIPAL'].fields_by_name['source_ip']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_PRINCIPAL'].fields_by_name['metadata']._loaded_options = None
  _globals['_PRINCIPAL'].fields_by_name['metadata']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_PRINCIPAL']._loaded_options = None
  _globals['_PRINCIPAL']._serialized_options = b'\232\305\210\036 \n\036envoy.config.rbac.v2.Principal'
  _globals['_ACTION'].fields_by_name['name']._loaded_options = None
  _globals['_ACTION'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATASOURCE']._serialized_start=4020
  _globals['_METADATASOURCE']._serialized_end=4060
  _globals['_RBAC']._serialized_start=594
  _globals['_RBAC']._serialized_end=1351
  _globals['_RBAC_AUDITLOGGINGOPTIONS']._serialized_start=803
  _globals['_RBAC_AUDITLOGGINGOPTIONS']._serialized_end=1198
  _globals['_RBAC_AUDITLOGGINGOPTIONS_AUDITLOGGERCONFIG']._serialized_start=1014
  _globals['_RBAC_AUDITLOGGINGOPTIONS_AUDITLOGGERCONFIG']._serialized_end=1120
  _globals['_RBAC_AUDITLOGGINGOPTIONS_AUDITCONDITION']._serialized_start=1122
  _globals['_RBAC_AUDITLOGGINGOPTIONS_AUDITCONDITION']._serialized_end=1198
  _globals['_RBAC_POLICIESENTRY']._serialized_start=1200
  _globals['_RBAC_POLICIESENTRY']._serialized_end=1277
  _globals['_RBAC_ACTION']._serialized_start=1279
  _globals['_RBAC_ACTION']._serialized_end=1317
  _globals['_POLICY']._serialized_start=1354
  _globals['_POLICY']._serialized_end=1703
  _globals['_SOURCEDMETADATA']._serialized_start=1706
  _globals['_SOURCEDMETADATA']._serialized_end=1872
  _globals['_PERMISSION']._serialized_start=1875
  _globals['_PERMISSION']._serialized_end=2858
  _globals['_PERMISSION_SET']._serialized_start=2697
  _globals['_PERMISSION_SET']._serialized_end=2805
  _globals['_PRINCIPAL']._serialized_start=2861
  _globals['_PRINCIPAL']._serialized_end=3934
  _globals['_PRINCIPAL_SET']._serialized_start=3633
  _globals['_PRINCIPAL_SET']._serialized_end=3737
  _globals['_PRINCIPAL_AUTHENTICATED']._serialized_start=3740
  _globals['_PRINCIPAL_AUTHENTICATED']._serialized_end=3876
  _globals['_ACTION']._serialized_start=3936
  _globals['_ACTION']._serialized_end=4018
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/postal_address.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/postal_address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n google/type/postal_address.proto\x12\x0bgoogle.type\"\xfd\x01\n\rPostalAddress\x12\x10\n\x08revision\x18\x01 \x01(\x05\x12\x13\n\x0bregion_code\x18\x02 \x01(\t\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x13\n\x0bpostal_code\x18\x04 \x01(\t\x12\x14\n\x0csorting_code\x18\x05 \x01(\t\x12\x1b\n\x13\x61\x64ministrative_area\x18\x06 \x01(\t\x12\x10\n\x08locality\x18\x07 \x01(\t\x12\x13\n\x0bsublocality\x18\x08 \x01(\t\x12\x15\n\raddress_lines\x18\t \x03(\t\x12\x12\n\nrecipients\x18\n \x03(\t\x12\x14\n\x0corganization\x18\x0b \x01(\tBx\n\x0f\x63om.google.typeB\x12PostalAddressProtoP\x01ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.postal_address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\022PostalAddressProtoP\001ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\370\001\001\242\002\003GTP'
  _globals['_POSTALADDRESS']._serialized_start=50
  _globals['_POSTALADDRESS']._serialized_end=303
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from envoy.service.event_reporting.v2alpha import event_reporting_service_pb2 as envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in envoy/service/event_reporting/v2alpha/event_reporting_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class EventReportingServiceStub(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamEvents = channel.stream_stream(
                '/envoy.service.event_reporting.v2alpha.EventReportingService/StreamEvents',
                request_serializer=envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsResponse.FromString,
                _registered_method=True)


class EventReportingServiceServicer(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    def StreamEvents(self, request_iterator, context):
        """Envoy will connect and send StreamEventsRequest messages forever.
        The management server may send StreamEventsResponse to configure event stream. See below.
        This API is designed for high throughput with the expectation that it might be lossy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventReportingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamEvents': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamEvents,
                    request_deserializer=envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsRequest.FromString,
                    response_serializer=envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.event_reporting.v2alpha.EventReportingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('envoy.service.event_reporting.v2alpha.EventReportingService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EventReportingService(object):
    """[#protodoc-title: gRPC Event Reporting Service]

    [#not-implemented-hide:]
    Service for streaming different types of events from Envoy to a server. The examples of
    such events may be health check or outlier detection events.
    """

    @staticmethod
    def StreamEvents(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/envoy.service.event_reporting.v2alpha.EventReportingService/StreamEvents',
            envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsRequest.SerializeToString,
            envoy_dot_service_dot_event__reporting_dot_v2alpha_dot_event__reporting__service__pb2.StreamEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v2alpha/mutex_stats.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v2alpha/mutex_stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/admin/v2alpha/mutex_stats.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1dudpa/annotations/status.proto\"`\n\nMutexStats\x12\x17\n\x0fnum_contentions\x18\x01 \x01(\x04\x12\x1b\n\x13\x63urrent_wait_cycles\x18\x02 \x01(\x04\x12\x1c\n\x14lifetime_wait_cycles\x18\x03 \x01(\x04\x42z\n!io.envoyproxy.envoy.admin.v2alphaB\x0fMutexStatsProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.mutex_stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\017MutexStatsProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_MUTEXSTATS']._serialized_start=93
  _globals['_MUTEXSTATS']._serialized_end=189
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/thrift_to_metadata/v3/thrift_to_metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/thrift_to_metadata/v3/thrift_to_metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.thrift_proxy.v3 import thrift_proxy_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_thrift__proxy__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLenvoy/extensions/filters/http/thrift_to_metadata/v3/thrift_to_metadata.proto\x12\x33\x65nvoy.extensions.filters.http.thrift_to_metadata.v3\x1a\x43\x65nvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"g\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12%\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\"\xa5\x01\n\rFieldSelector\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x02id\x18\x02 \x01(\x05\x42\x14\xfa\x42\x11\x1a\x0f\x18\xff\xff\x01(\x80\x80\xfe\xff\xff\xff\xff\xff\xff\x01\x12Q\n\x05\x63hild\x18\x03 \x01(\x0b\x32\x42.envoy.extensions.filters.http.thrift_to_metadata.v3.FieldSelector:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\"\x84\x03\n\x04Rule\x12I\n\x05\x66ield\x18\x01 \x01(\x0e\x32:.envoy.extensions.filters.http.thrift_to_metadata.v3.Field\x12\x64\n\x0e\x66ield_selector\x18\x02 \x01(\x0b\x32\x42.envoy.extensions.filters.http.thrift_to_metadata.v3.FieldSelectorB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12\x1d\n\x0bmethod_name\x18\x03 \x01(\tB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12U\n\non_present\x18\x04 \x01(\x0b\x32\x41.envoy.extensions.filters.http.thrift_to_metadata.v3.KeyValuePair\x12U\n\non_missing\x18\x05 \x01(\x0b\x32\x41.envoy.extensions.filters.http.thrift_to_metadata.v3.KeyValuePair\"\xbe\x03\n\x10ThriftToMetadata\x12P\n\rrequest_rules\x18\x01 \x03(\x0b\x32\x39.envoy.extensions.filters.http.thrift_to_metadata.v3.Rule\x12Q\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.filters.http.thrift_to_metadata.v3.Rule\x12\\\n\ttransport\x18\x03 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x04 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12)\n\x13\x61llow_content_types\x18\x05 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x12 \n\x18\x61llow_empty_content_type\x18\x06 \x01(\x08\"\xc9\x01\n\x18ThriftToMetadataPerRoute\x12P\n\rrequest_rules\x18\x01 \x03(\x0b\x32\x39.envoy.extensions.filters.http.thrift_to_metadata.v3.Rule\x12Q\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.filters.http.thrift_to_metadata.v3.Rule:\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01*z\n\x05\x46ield\x12\x0f\n\x0bMETHOD_NAME\x10\x00\x12\x0c\n\x08PROTOCOL\x10\x01\x12\r\n\tTRANSPORT\x10\x02\x12\x10\n\x0cHEADER_FLAGS\x10\x03\x12\x0f\n\x0bSEQUENCE_ID\x10\x04\x12\x10\n\x0cMESSAGE_TYPE\x10\x05\x12\x0e\n\nREPLY_TYPE\x10\x06\x42\xd5\x01\nAio.envoyproxy.envoy.extensions.filters.http.thrift_to_metadata.v3B\x15ThriftToMetadataProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/thrift_to_metadata/v3;thrift_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.thrift_to_metadata.v3.thrift_to_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.http.thrift_to_metadata.v3B\025ThriftToMetadataProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/thrift_to_metadata/v3;thrift_to_metadatav3\272\200\310\321\006\002\020\002'
  _globals['_KEYVALUEPAIR'].fields_by_name['key']._loaded_options = None
  _globals['_KEYVALUEPAIR'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FIELDSELECTOR'].fields_by_name['name']._loaded_options = None
  _globals['_FIELDSELECTOR'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FIELDSELECTOR'].fields_by_name['id']._loaded_options = None
  _globals['_FIELDSELECTOR'].fields_by_name['id']._serialized_options = b'\372B\021\032\017\030\377\377\001(\200\200\376\377\377\377\377\377\377\001'
  _globals['_FIELDSELECTOR']._loaded_options = None
  _globals['_FIELDSELECTOR']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_RULE'].fields_by_name['field_selector']._loaded_options = None
  _globals['_RULE'].fields_by_name['field_selector']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_RULE'].fields_by_name['method_name']._loaded_options = None
  _globals['_RULE'].fields_by_name['method_name']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_THRIFTTOMETADATA'].fields_by_name['transport']._loaded_options = None
  _globals['_THRIFTTOMETADATA'].fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_THRIFTTOMETADATA'].fields_by_name['protocol']._loaded_options = None
  _globals['_THRIFTTOMETADATA'].fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_THRIFTTOMETADATA'].fields_by_name['allow_content_types']._loaded_options = None
  _globals['_THRIFTTOMETADATA'].fields_by_name['allow_content_types']._serialized_options = b'\372B\t\222\001\006\"\004r\002\020\001'
  _globals['_THRIFTTOMETADATAPERROUTE']._loaded_options = None
  _globals['_THRIFTTOMETADATAPERROUTE']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_FIELD']._serialized_start=1638
  _globals['_FIELD']._serialized_end=1760
  _globals['_KEYVALUEPAIR']._serialized_start=321
  _globals['_KEYVALUEPAIR']._serialized_end=424
  _globals['_FIELDSELECTOR']._serialized_start=427
  _globals['_FIELDSELECTOR']._serialized_end=592
  _globals['_RULE']._serialized_start=595
  _globals['_RULE']._serialized_end=983
  _globals['_THRIFTTOMETADATA']._serialized_start=986
  _globals['_THRIFTTOMETADATA']._serialized_end=1432
  _globals['_THRIFTTOMETADATAPERROUTE']._serialized_start=1435
  _globals['_THRIFTTOMETADATAPERROUTE']._serialized_end=1636
# @@protoc_insertion_point(module_scope)
